package proyecto.Android.webService.persistencia;

import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NameClassPair;
import javax.naming.NamingEnumeration;
import javax.servlet.ServletContext;
import javax.servlet.ServletContextEvent;
import javax.servlet.ServletContextListener;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * Esta clase es un Listener, que se encarga, en el arranque, de acceder a las variables
 * de configuraci�n al arranque de la aplicaci�n e introduce en el ServletContext sus valores
 * @author Jos� Alejandro Crisol (ELIMCO SISTEMAS)
 */
public class ArranqueServletContextListener implements ServletContextListener {


    protected Log log = LogFactory.getFactory().getInstance(this.getClass());
    /**
     * Inicializaci�n de los paramteros de configuracion del sistema
     * Llama al m�todo que introduce las variables en el contexto
     * @param sce
     * @author: Jose Alejandro Crisol (ELIMCO SISTEMAS)
     */
    public void contextInitialized(ServletContextEvent sce) {
       log.info("Inicializando Contexto");
       try {
           colocarVariablesEnContexto(sce.getServletContext());
       } catch (Exception e) {
           log.error(e.getMessage());
       }
    }

    /**
     * Metodo de destruccion de contexto
     * No hacemos nada
     * @param sce
     * @author: Jose Alejandro Crisol (ELIMCO SISTEMAS)
     */
    public void contextDestroyed(ServletContextEvent sce) {
        return ;
    }


    private void colocarVariablesEnContexto(ServletContext context) {
        Context initCtx;
        try {
            initCtx = new InitialContext();
            Context contextInit = (Context) initCtx.lookup("java:comp/env");
            // recuperamos TODOS todos los parametros
            NamingEnumeration<NameClassPair> propiedadesJDNI = contextInit.list("");
            while (propiedadesJDNI.hasMoreElements()) {
                NameClassPair propiedad = propiedadesJDNI.nextElement();
                //Aqui recuperamos el nombre de la propiedad
                String nombrePropiedad = propiedad.getName();
                //Aqui recuperamos el valor
                Object temp = contextInit.lookup(nombrePropiedad);
                //Si son Strings, son nuestras variables
                if (temp instanceof String) {
                    String valor = (String) temp;
                    log.info(nombrePropiedad + "=" + valor);
                    //Colocamos las variables en contexto
                    context.setAttribute(nombrePropiedad, valor);
                }
            }

        } catch (Exception e) {
            log.error(e.getMessage());
        }
    }


}
